@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2017
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -29,11 +29,23 @@ color.scale <- function(z, col = tim.colors(256),
     }
     z[(z < zlim[1]) | (z > zlim[2])] <- NA
     NC <- length(col)
-    breaks <- seq(zlim[1] * (1 - eps), zlim[2] * (1 + eps), , 
-        NC + 1)
+    span<- zlim[2]-zlim[1]
+    # expand breaks slightly to include obs on the boundaries. 
+    breaks <- seq(zlim[1] - span*eps,
+                  zlim[2] + span*eps , 
+                    length.out= NC + 1)
     # the magic of R ...
     icolor <- cut(c(z), breaks)@.Data
     # returned values is a vector of character hex strings encoding the colors.
-    ifelse(is.na(icolor), transparent.color, col[icolor])
+     colorMap<- ifelse(is.na(icolor),
+                         transparent.color, col[icolor])
+# add zlim and col table as attributes so one can add
+# legend.     
+    attr( colorMap,"zlim")<- zlim
+    attr(colorMap,"col")<- col
+    # potential hooks for colorBar functions
+    #colorMapInfo<- list( col=col, zlim=zlim)
+    #assign( ".colorMapInfo", colorMapInfo, pos=1)
+    return( colorMap)
 }
 
